*****************
Utility Functions
*****************
These functions perform various small operations within `Multidrizzle`.

.. moduleauthor:: Warren Hack <help@stsci.edu>

.. automodule:: drizzlepac.util
   :members:
   :undoc-members:


